@@ -13,7 +13,7 @@ protected:
 		return getStatCollection()->TimeStatistics();
 	}
 	
-	virtual void startLine(Plot2D &plot, const std::string &name, const std::string &yAxisDesc) override final
+	virtual void startLine(Plot2D &plot, const std::string &name, int lineIndex, const std::string &yAxisDesc) override final
 	{
 		plot.StartLine(name, "Time", yAxisDesc, true);
 	}
