@@ -23,6 +23,8 @@ ImagePropertiesWindow::ImagePropertiesWindow(HeatMapWidget &imageWidget, const s
 	_blackRedScaleButton("Black/red"),
 	_redBlueYellowScaleButton("Red/Yellow/Blue"),
 	_fireScaleButton("Fire"),
+	_cubeHelixScaleButton("Cubehelix"),
+	_cubeHelixColourfulScaleButton("Cubehelix+"),
 	_viridisScaleButton("Viridis"),
 	
 	_scaleFrame("Scale"),
@@ -112,6 +114,12 @@ void ImagePropertiesWindow::initColorMapButtons()
 	_fireScaleButton.set_group(group);
 	_colorMapBox.pack_start(_fireScaleButton);
 	
+	_cubeHelixScaleButton.set_group(group);
+	_colorMapBox.pack_start(_cubeHelixScaleButton);
+	
+	_cubeHelixColourfulScaleButton.set_group(group);
+	_colorMapBox.pack_start(_cubeHelixColourfulScaleButton);
+	
 	_viridisScaleButton.set_group(group);
 	_colorMapBox.pack_start(_viridisScaleButton);
 	
@@ -125,6 +133,8 @@ void ImagePropertiesWindow::initColorMapButtons()
 		case HeatMapPlot::BlackRedMap: _blackRedScaleButton.set_active(true); break;
 		case HeatMapPlot::RedYellowBlueMap: _redBlueYellowScaleButton.set_active(true); break;
 		case HeatMapPlot::FireMap: _fireScaleButton.set_active(true); break;
+		case HeatMapPlot::CubeHelixMap: _cubeHelixScaleButton.set_active(true); break;
+		case HeatMapPlot::CubeHelixColourfulMap: _cubeHelixColourfulScaleButton.set_active(true); break;
 		case HeatMapPlot::ViridisMap: _viridisScaleButton.set_active(true); break;
 	}
 
@@ -304,6 +314,10 @@ void ImagePropertiesWindow::onApplyClicked()
 		_imageWidget.Plot().SetColorMap(HeatMapPlot::RedYellowBlueMap);
 	else if(_fireScaleButton.get_active())
 		_imageWidget.Plot().SetColorMap(HeatMapPlot::FireMap);
+	else if(_cubeHelixScaleButton.get_active())
+		_imageWidget.Plot().SetColorMap(HeatMapPlot::CubeHelixMap);
+	else if(_cubeHelixColourfulScaleButton.get_active())
+		_imageWidget.Plot().SetColorMap(HeatMapPlot::CubeHelixColourfulMap);
 	else if(_viridisScaleButton.get_active())
 		_imageWidget.Plot().SetColorMap(HeatMapPlot::ViridisMap);
 	
